{% extends "allianceauth/base.html" %}
{% load static %}
{% load i18n %}

{% block page_title %}{% trans "Services Management" %}{% endblock page_title %}
{% block extra_css %}{% endblock extra_css %}

{% block content %}
    <div>
        <h1 class="page-header text-center">{% trans "Available Services" %}</h1>
        <div class="table-responsive">
            <table class="table table-striped">
                <thead>
                    <tr>
                        <th class="text-center">{% trans "Service" %}</th>
                        <th class="text-center">{% trans "Username" %}</th>
                        <th class="text-center">{% trans "Domain" %}</th>
                        <th class="text-center">{% trans "Action" %}</th>
                    </tr>
                </thead>
                <tbody>
                    {% for svc in service_ctrls %}
                        {{ svc }}
                    {% endfor %}
                </tbody>
            </table>
        </div>
    </div>

{% endblock content %}
