{% extends 'public/middle_box.html' %}

{% load i18n %}
{% load static %}

{% block page_title %}Login{% endblock %}

{% block middle_box_content %}
    <p style="text-align: center">
        <img class="login-image" src="https://images.evetech.net/corporations/98000030/logo?size=256">
    </p>

    <p style="text-align: center; font-size: 150%;">
        Terra Nanotech<br>
        Authentication System
    </p>

    <p style="text-align: center">
        <a class="sso-login-button" href="{% url 'auth_sso_login' %}{% if request.GET.next %}?next={{request.GET.next}}{%endif%}">
            <svg>
                <use xlink:href="#tnnt-aa-svg-sso"/>
            </svg>
        </a>
    </p>

    <p style="text-align: center;">
        {% translate "For information on SSO, ESI and security read the CCP Dev Blog" %}<br><a href="https://www.eveonline.com/article/introducing-esi" target="_blank">Introducing ESI - A New API For Eve Online</a>
    </p>

    <p style="text-align: center;">
        <a href="https://community.eveonline.com/support/third-party-applications/" target="_blank">
            {% translate "Manage ESI Applications" %}
        </a>
    </p>
{% endblock %}
