@media all {
    .auth-member-groups .label-dashboard-group-name:first-child {
        margin-left: 0;
    }

    .auth-member-groups .label-dashboard-group-name:last-child {
        margin-right: 0;
    }

    .auth-member-groups .label-dashboard-group-name {
        margin: 0 0.3125rem 0.625rem 0.3125rem;
    }
}
