/* General DataTables styles
------------------------------------------------------------------------------------- */
@media all {
    .dataTables_wrapper > .form-inline {
        margin-bottom: 0.625rem;
    }

    .dataTables_wrapper > .form-inline select {
        margin-right: 0.625rem;
        margin-bottom: 0.625rem;
    }

    .dataTables_wrapper > .form-inline select:last-child {
        margin-right: 0;
    }

    .dataTables_length select {
        margin: 0 0.625rem;
    }
}

@media (min-width: 768px) {
    .dataTables_wrapper > .form-inline select:first-child {
        margin-left: 0.625rem;
    }
}

/* ---------------------------------------------------------------------------------- */

/* App: Fittings
------------------------------------------------------------------------------------- */
@media all {
    .aa-fittings-add-dropdown {
        margin-bottom: 0.5em;
    }
}

@media all and (min-width: 768px) {
    .aa-fittings-add-dropdown {
        margin-bottom: 0;
        margin-top: 0.5em;
    }
}

/* ---------------------------------------------------------------------------------- */

/* App: AA Blueprints
------------------------------------------------------------------------------------- */
@media all {
    .template-light-mode .aa-blueprints .table-striped > tbody > tr.tr-group,
    .template-light-mode .aa-blueprints .tr-group {
        font-weight: bold;
        background-color: rgb(62, 68, 76) !important;
    }
}

/* ---------------------------------------------------------------------------------- */

/* App :: AA Memberaudit
------------------------------------------------------------------------------------- */
@media all {
    .template-light-mode .aa-memberaudit .sidebar_character > a,
    .template-dark-mode .aa-memberaudit .sidebar_character > a {
        color: rgb(255, 255, 255);
    }

    .template-light-mode .aa-memberaudit .sidebar_character:hover > a,
    .template-light-mode .aa-memberaudit .sidebar_character.active > a,
    .template-dark-mode .aa-memberaudit .sidebar_character:hover > a,
    .template-dark-mode .aa-memberaudit .sidebar_character.active > a {
        background-color: rgb(34, 34, 34);
    }

    .template-light-mode .aa-memberaudit .nav-tabs > li.active > a,
    .template-dark-mode .aa-memberaudit .nav-tabs > li.active > a {
        background-color: rgb(70, 69, 69) !important;
        color: rgb(255, 255, 255) !important;
    }

    .template-light-mode .aa-memberaudit .table > tbody > .table-group > td,
    .template-light-mode .aa-memberaudit .table > tbody > .table-group > td {
        background-color: rgb(62, 68, 76);
        color: rgb(255, 255, 255);
        font-weight: bold;
    }

    .template-light-mode .aa-memberaudit .cards_container .card,
    .template-dark-mode .aa-memberaudit .cards_container .card {
        background-color: rgba(100, 100, 100, 0.5);
    }
}

/* ---------------------------------------------------------------------------------- */

/* App: AA Sovtimer
------------------------------------------------------------------------------------- */
@media all {
    .aa-sovtimer .table > tbody > tr > td {
        vertical-align: middle;
    }

    .aa-sovtimer .aa-sovtimer-trend {
        display: inline-block;
        cursor: default;
        position: relative;
        top: 0.34375rem;
        left: 0.3125rem;
        margin-right: 0.625rem;
    }

    .aa-sovtimer .aa-sov-timer-zkb-icon {
        margin-left: 0.5rem;
    }

    .aa-sovtimer .aa-sov-timer-zkb-icon > img {
        position: relative;
        top: -2px;
    }

    .aa-sovtimer .aa-sovtimer-campaigns tr td:last-child {
        padding-top: 0;
        white-space: nowrap;
    }

    .aa-sovtimer .aa-sovtimer-remaining {
        text-shadow: 1px 1px 1px rgba(0, 0, 0, 0.3);
    }
}
