@media all {
    *,
    *::before,
    *::after {
        box-sizing: border-box;
    }

    body {
        margin: 0;
        font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto,
        "Helvetica Neue", Arial, "Noto Sans", sans-serif,
        "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol",
        "Noto Color Emoji";
        font-size: 1rem;
        font-weight: 400;
        line-height: 1.5;
        color: rgb(33, 37, 41);
        text-align: left;
        background-color: rgb(255, 255, 255);
    }

    .bg-dark {
        background-color: rgb(52, 58, 64);
    }

    .container {
        width: 100%;
        padding-right: 1rem;
        padding-left: 1rem;
        margin-right: auto;
        margin-left: auto;
        margin-top: 3rem;
    }

    .container-inner {
        flex: 0 0 50%;
        width: 75%;
        max-width: 1450px;
        margin: 0 auto;
    }

    .card {
        position: relative;
        display: -ms-flexbox;
        display: flex;
        -ms-flex-direction: column;
        flex-direction: column;
        min-width: 0;
        word-wrap: break-word;
        background-color: rgb(255, 255, 255);
        background-clip: border-box;
        border: 1px solid rgba(0, 0, 0, .125);
        border-radius: 0.25rem;
    }

    .card-header, .card-footer {
        padding: 0.75rem 1.25rem;
        margin-bottom: 0;
        background-color: rgba(0, 0, 0, 0.03);
        border-bottom: 1px solid rgba(0, 0, 0, 0.125);
        text-align: center;
    }

    .card-footer {
        border-bottom: none;
        border-top: 1px solid rgba(0, 0, 0, 0.125);
    }

    .card-header:first-child {
        border-radius: calc(0.25rem - 1px) calc(0.25rem - 1px) 0 0;
    }

    .card-body {
        -ms-flex: 1 1 auto;
        flex: 1 1 auto;
        min-height: 1px;
        padding: 1.25rem;
    }

    .cards_container {
        display: flex;
        flex-wrap: wrap;
        list-style: none;
        margin: 0 -1rem 2rem -1rem;
        padding: 0;
        justify-content: center;
    }

    .cards_item {
        display: flex;
        padding: 1rem;
    }

    .cards_item .card {
        display: flex;
        flex-direction: column;
    }

    img {
        max-width: 100%;
    }

    .text-center {
        text-align: center;
    }

    form {
        margin-bottom: 0.3rem;
    }

    .btn-select-character {
        width: 100%;
        padding: 0.15rem;
        cursor: pointer;
    }

    .btn-new-character-sso,
    .btn-character-image {
        padding: 0;
        border: none;
        cursor: pointer;
    }

    .label-requested-esi-scope {
        display: inline-block;
        min-width: 10px;
        padding: 3px 7px;
        font-size: 1rem;
        line-height: 1;
        text-align: center;
        white-space: nowrap;
        vertical-align: middle;
        background-color: rgb(44, 62, 80);
        color: rgb(255, 255, 255);
        /*background-color: rgb(192, 192, 192);*/
        /*color: rgb(54, 54, 54);*/
        border-radius: 5px;
    }
}

@media (min-width: 40rem) {
    .cards_container .cards_item {
        width: calc(100% / 2);
    }
}

@media (min-width: 56rem) {
    .cards_container .cards_item {
        width: calc(100% / 3);
    }
}

@media (min-width: 75rem) {
    .cards_container .cards_item {
        width: calc(100% / 4);
    }
}

@media (min-width: 90rem) {
    .cards_container .cards_item {
        width: calc(100% / 5);
    }
}

@media (min-width: 105rem) {
    .cards_container .cards_item {
        width: calc(100% / 6);
    }
}
