@media all {
    body {
        background: url('https://web.ccpgamescdn.com/aws/eveonline/sso/background.jpg') no-repeat center center fixed;
        -webkit-background-size: cover;
        -moz-background-size: cover;
        -o-background-size: cover;
        background-size: cover;
    }

    .auth-login-box {
        margin: 0;
        position: absolute;
        top: 0;
        bottom: 0;
        width: 100%;
        background: rgba(48,48,48,0.75);
    }

    .login-image {
        border-radius: 50%;
    }

    .auth-login-box-inner {
        position: absolute;
        bottom: 5vh;
        width: 100%;
    }

    .panel-transparent {
        background: transparent;
        color: rgb(255,255,255);
        border: none;
    }

    .panel-body {

    }

    #lang-select {
        width: 40%;
        margin-left: auto;
        margin-right: auto;
    }

    .sso-login-button {
        width: 270px;
        height: 45px;
        margin-top: 10px;
        margin-bottom: 15px;
        color: rgb(173, 173, 173);
        filter: drop-shadow(0 4px 5px rgba(0,0,0,0.4));
        transition: color 0.18s ease-out, filter 0.06s ease-out;
        will-change: color, fill;
    }

    .sso-login-button:hover {
        color: rgb(226, 138, 13);
        filter: drop-shadow(0 1px 3px rgba(0,0,0,0.4));
    }

    .sso-login-button > svg {
        width: inherit;
        height: inherit;
    }

    .tnnt-aa-svg-wrapper {
        width: 0;
        height: 0;
        overflow: hidden;
    }
}

@media all and (min-width: 500px) {
    .auth-login-box {
        left: 10vw;
        width: 40rem;
    }

    .auth-login-box-inner {
        bottom: 10vh;
    }

    .login-image {
        opacity: 0.3;
        transition: opacity 0.5s ease-in-out;
        -moz-transition: opacity 0.5s ease-in-out;
        -webkit-transition: opacity 0.5s ease-in-out;
    }

    .auth-login-box-inner:hover .login-image {
        opacity: 1;
    }
}
